%caesar
% Function which loads a .txt file and applies a very simple caesar shift
% encryption on the letters of the alphabet.
%
% LAST UPDATED by Andy French. April 2016

function caesar

%% Inputs %

% Define Caesar shift alphabet, and cipher alphabet
a = 'abcdefghijklmnopqrstuvwxyz';
A = 'ABCDEFGHIJKLMNOPQRSTUVWXYZ';
original_alphabet = [a,A];
a = 'zabcdefghijklmnopqrstuvwxy';
A = 'ZABCDEFGHIJKLMNOPQRSTUVWXY';
cipher_alphabet = [a,A];

%Note any other ASCII characters will not be encrypted

%

%Display opening message to command window
disp(' ')
disp(' %%%%%%%%%%%%%%%%%%%%%%%%' )
disp('  Caesar Shift Encryptor ' )
disp(' %%%%%%%%%%%%%%%%%%%%%%%%' )
disp(' ')
disp(' Choose file(s) to encrypt or decrypt...' )
disp(' ')

%Find plaintext text file to encrypt or decrypt
[filename, pathname] = uigetfile( '*.txt',...
    'select location of text file(s)...', ...
    'multiselect', 'on');
if iscell(filename)==0
    %Store filename in a cell array, if just one file has been chosen.
    %This means we don't have to consider the single file case separately
    %later.
    if filename == 0
        return
    else
        filename = {filename};
    end
end

%Choose encrypt or decrypt option
choice = questdlg('choose encryption option', ...
    'encryption option', ...
    'encrypt','decrypt',...
    'encrypt');
if strcmp(choice,'')
    return
end

%Start clock
t0 = tic;

% Handle response
switch choice
    case 'encrypt'
        cipherbet = cipher_alphabet;
        alphabet = original_alphabet;
        method = '-e';
    case 'decrypt'
        cipherbet = original_alphabet;
        alphabet = cipher_alphabet;
        method = '-d';
end

%Loop through selected files and encrypt or decrypt
for n=1:numel(filename)
    
    %Open file filename (read only)
    fid = fopen( [pathname,filename{n}], 'r' );
    
    %Store filename text in a row vector of ascii characters
    t = fscanf(fid, '%c');
    
    %Close file
    fclose(fid); clear fid
    
    %Step through t and exchange letters that belong to the alphabet with
    %corresponing ones from the cipherbet.
    for m=1:length(t)
        %Find index of plaintext character in alphabet vector
        i = strfind( alphabet, t(m) );
        
        %Replace by corresponding character in cipherbet
        if isempty(i)==0
            t(m) = cipherbet(i);
        end
    end
    
    %Write out encrypted (or decrypted) file
    fid = fopen( strrep( [pathname,filename{n} ],'.txt',...
        [method,'.txt'] ),'w+' );
    fwrite( fid, t );
    fclose(fid);
    
    %Display message to command window
    if strcmp( method, '-e')==1
        disp([' File ',filename{n},' encrypted.'])
    end
    
end

%Stop clock and display completion message
disp(' ');
disp([' All ',num2str(numel(filename)),...
    ' files processed in ',num2str(toc(t0)),' seconds.']);
disp(' ');

%end of code