%duotone
% Function which loads a bitmap image and writes it out as
% a duotone JPEG image.
%
% LAST UPDATED by Andy French April 2016

function duotone

%Set fontsize of plot annotation
fsize = 18;

%

%Display message to command window
disp(' ')
disp(' %%%%%%%%%%%%%%%%%%%%%' )
disp('  Duotone image maker ' )
disp(' %%%%%%%%%%%%%%%%%%%%%' )
disp(' ')
disp(' Choose file(s) to turn into duotone images...' )
disp(' ')

%Chose image file to load
[filename, pathname] = uigetfile( {'*.jpg;*.bmp;*.png;*.gif;*tif',...
    'Bitmap images (*.jpg,*.bmp,*.png,*.gif,*.tif)'},...
    'Select location of image file(s)...', ...
    'multiselect', 'on' );
if iscell(filename)==0
    if filename == 0
        return
    else
        filename = {filename};
    end
end

%Choose R,G,B colours for duotone image.
disp(' Set duotone colours .... ')
rgb1 = uisetcolor('Choose duotone colour 1');
rgb2 = uisetcolor('Choose duotone colour 2');
disp(' ')

%Start clock
t0 = tic;

%Step through files, and export a duotone version of the images
for n=1:length(filename)
    
    %Display message to command window
    disp([' Processing file ',filename{n} ])
    
    %Load image into an NxMx3 matrix of values. i.e. Red, Green and Blue colour
    %planes. cmap is the local colormap associated with the image, and alpha is
    %a matrix which defines the transparency of the image
    [I,cmap,alphamap] = imread( [ pathname,filename{n} ] );
    info = imfinfo( [ pathname,filename{n} ] );
    dim = size(I);
    
    %Set the colour matrix to be within the range 0...1, and a double precision
    %number. Most full colour images are stored as 8 bit integers.
    if numel(dim) == 2
        %An indexed image like a GIF has a colourmap rather than three R,G,B
        %colour intensities.
        I = 255*ind2rgb(I,cmap);
    end
    I = double(I)/255;
    
    %Sum over colour planes to make an overall intensity. Store these in a
    %two dimensional marix II.
    I = (1/3)*sum(I,3);
    A = ones(dim(1),dim(2));
    II = A;
    II(:,:) = I(:,:,1);
    
    %Set R,G,B colour matrices of duotone image
    R = rgb1(1)*(A - II) + II*rgb2(1);
    G = rgb1(2)*(A - II) + II*rgb2(2);
    B = rgb1(3)*(A - II) + II*rgb2(3);
    
    %Save dutone image as a JPEG
    I(:,:,1) = R;
    I(:,:,2) = G;
    I(:,:,3) = B;
    imwrite( I,...
        strrep( [pathname,'duotone ',filename{n} ],info.Format,'.jpg'),...
        'jpg' );
end

%Display completion message
disp(' ');
disp([ ' All files converted to duotone images in ',num2str(toc(t0)),' seconds.']);
disp(' ')

%End of code