%image2fig
% Function which loads a bitmap image into a MATLAB figure window.
%
% LAST UPDATED by Andy French April 2016

function image2fig

%Set fontsize of plot annotation
fsize = 18;

%

%Chose image file to load
[filename, pathname] = uigetfile( {'*.jpg;*.bmp;*.png;*.gif;*tif',...
    'Bitmap images (*.jpg,*.bmp,*.png,*.gif,*.tif)'},...
    'Select location of image file(s)...', ...
    'multiselect', 'off' );
if filename == 0
    return
end

%Load image into an NxMx3 matrix of values. i.e. Red, Green and Blue colour
%planes. cmap is the local colormap associated with the image, and alpha is
%a matrix which defines the transparency of the image
[I,cmap,alphamap] = imread( [pathname,filename] );

%Get image information stored within the file
info = imfinfo( [pathname,filename] )
dim = size(I);

%Set the colour matrix to be within the range 0...1, and a double precision
%number. Most full colour images are stored as 8 bit integers.
if numel(dim) == 2
    %An indexed image like a GIF has a colourmap rather than three R,G,B
    %colour intensities.
    I = 255*ind2rgb(I,cmap);
end
I = double(I)/255;

%Flip image, as pixel(1,1) is by convention the top left rather than the
%bottom left.
I = flipdim(I,1);

%Create a figure and plot the image
figure('color',[1 1 1],'name',filename)
x = 1:dim(2);
y = 1:dim(1);
[x,y] = meshgrid(x,y);
z = ones(dim(1),dim(2));
surf(x,y,z,I);
if isempty(alphamap)==0
    alpha(alphamap);
end
shading interp
view(2);
axis equal
axis tight
box on
xlabel('x pixels','fontsize',fsize);
ylabel('y pixels','fontsize',fsize);
title( filename, 'fontsize',fsize);
set(gca,'fontsize',fsize)

%End of code