%image2txt
% Function which loads a bitmap image and turns this into a text file.
%
% LAST UPDATED by Andy French May 2016

function image2txt

%Set number of characters which constitute the width of the text file
Nwidth = 150;

%Define characters for levels of grey
grey = {
    ' ',...
    'o',...
    'q',...
    'w',...
    'i',...
    'x',...
    'z',...
    '',...
    '$',...
    '.',...
    '*' };

%

%Chose image file to load
[filename, pathname] = uigetfile( {'*.jpg;*.bmp;*.png;*.gif;*tif',...
    'Bitmap images (*.jpg,*.bmp,*.png,*.gif,*.tif)'},...
    'Select location of image file(s)...', ...
    'multiselect', 'off' );
if filename == 0
    return
end

%Load image into an NxMx3 matrix of values. i.e. Red, Green and Blue colour
%planes. cmap is the local colormap associated with the image, and alpha is
%a matrix which defines the transparency of the image
[I,cmap,alphamap] = imread( [pathname,filename] );

%Get image information stored within the file
info = imfinfo( [pathname,filename] );
dim = size(I);

%Set the colour matrix to be within the range 0...1, and a double precision
%number. Most full colour images are stored as 8 bit integers.
if numel(dim) == 2
    %An indexed image like a GIF has a colourmap rather than three R,G,B
    %colour intensities.
    I = 255*ind2rgb(I,cmap);
end
I = double(I)/255;

%Turn into a single matrix
II = ones(dim(1),dim(2));
I = sum(I,3)/3;
II(:,:) = I(:,:,1);
I = II;
clear II;

%Interpolate to be Nwidth wide. To account for line spacing being greater
%than character spacing, reduce y interpolation by a factor of 2
[x,y] = meshgrid( 1:dim(2), 1:dim(1) );
[xx,yy] = meshgrid( linspace( 1,dim(2), Nwidth ),...
    linspace( 1,dim(1), round( 0.5*dim(1)*Nwidth/dim(2) ) ) );
I = interp2( x,y, I, xx, yy );

%Invert image, so black is 1
I = ones(size(I)) - I;

%Determine grey boundaries
greyb = linspace( 0,1, length(grey) );

%Construct text file based upon I. Do this via a character vector C, with
%line return characters every Nwidth pixels
C='';
dim = size(I);
for n=1:dim(1)
    for m=1:dim(2)
        
        %Determine nearest boundary value to I(n,m)
        for k=1:length(greyb)
            if I(n,m) <= greyb(k)
                C = [C,grey{k}];
                break;
            end
        end
        
    end
    %Add a line return character
    C = [C,char(10)];
end

%Write out text file
fid = fopen([pathname,filename,'.txt' ],'w' );
fwrite( fid, C );
fclose(fid);

%End of code