%mp3reverse
% Loads MP3 sound file(s) and reverses them.
%
% LAST UPDATED by Andy French April 2016

function mp3reverse

%Add directory mp3 to path (including all subdirectories)
addpath(genpath('mp3'));

%Display message to command window
disp(' ')
disp(' %%%%%%%%%%%%%%')
disp('  mp3 reverser ')
disp(' %%%%%%%%%%%%%%')
disp(' ')

%Use standard Windows file navigation box to find .mp3 files. More than one
%can be selected.
disp(' Choose .mp3 file(s)...' )
[filename, pathname] = uigetfile( '*.mp3',...
    'Choose .mp3 files....', ...
    'MultiSelect', 'on');
if iscell(filename)==0
    if filename==0
        return
    else
        filename = {filename};
    end
end

%Start clock
t0 = tic;
t = 0;

%Step through filenames and reverse MP3 files
for n=1:length(filename)
    %Load .mp3 file (s is a vector of sound samples, sampled at
    %frequency Fs Hz, with maximum (signed) amplitude 2^(Nbits-1)
    file = [ pathname, filename{n} ];
    [s,Fs,Nbits] = mp3read( file );
    
    %Reverse and write a .mp3 file with _r file appendage
    mp3write( flipud(s), Fs, strrep( file,'.mp3','-rev.mp3' ) );
    
    %Determine current elapsed time
    tt = toc(t0);
    
    %Display completion message
    disp(' ')
    disp([' File ',num2str(n),' of ',num2str(length(filename)),' : ',filename{n}]);
    disp([' Processed in ', num2str(tt-t),' seconds.'])
    disp([' Total elapsed time is ',num2str(tt),' seconds.']);
    
    %Update current time to enable individual file conversion time
    %calculation
    t=tt;
end

%Display completion message
disp(' ')
disp(' .mp3 reversal complete.')
disp(' ')

%Remove directory mp3 from path, including any subdirectories
rmpath(genpath('mp3'));

%End of code