%plotstock
% This program loads an Excel sheet containing FTSE100 or NASDAQ stock
% market data. A graph is plotted and the resulting data is saved as a .mat file.
%
% FTSE data from https://finance.yahoo.com/q/hp?s=%5EFTSE+Historical+Prices
% NASDAQ data from https://uk.finance.yahoo.com/q/hp?s=%5EIXIC
%
% LAST UPDATED by Andy French April 2016

function plotstock

%Set fontsize for graphs
fsize = 18;

%

%Find stock market Excel file
[filename, pathname] = uigetfile( '*.xls',...
    'Select location of stock market data Excel file...', ...
    'MultiSelect', 'off');
if filename == 0
    return
end

%Import Excel file into MATLAB. num is a matrix of just the numeric data,
%txt is an array of just te text data, and raw is a cell array containing
%everything in the spreadsheet. Note date is in reverse chronological order
%(i.e.most recent first)
[num,txt,raw] = xlsread( [ pathname,filename ] );

%Extract data and store in row vectors (hence .' transposition operation)
date_str = raw( 2:end, 1 ).';
opening_value = num(1:end,1 ).';
high_value = num(1:end,2 ).';
low_value = num(1:end,3 ).';
close_value = num(1:end,4 ).';
volume_of_shares = num(1:end,5 ).';
adjusted_close_value = num(1:end,6 ).';

%Calculate number of days worth of data
N = numel(opening_value);

%Convert time string into years since the first date
t = datenum( date_str,'dd/mm/yyyy'  ) - datenum( date_str{end},'dd/mm/yyyy' );
t = t/365;

%Plot adjusted close value vs time
figure('color',[1 1 1],'name',filename)
plot(t,adjusted_close_value);
xlim([0,max(t)])
xlabel([ 'Years since ',date_str{N} ],'fontsize',fsize);
ylabel('Adjusted closing value','fontsize',fsize)
title([strrep(filename,'.xls',''),' index values from ',...
    date_str{N},' to ',date_str{1}],'fontsize',fsize)
set(gca,'fontsize',fsize)
grid on;

%Save a .png file of the graph
print( gcf, strrep([pathname,filename],'.xls','.png'), '-dpng','-r300' );

%Clear unwanted variables
clear num txt raw

%Save as a .mat file
save( strrep([pathname,filename],'.xls','.mat') )

%End of code