%primefactors
% Function which creates a text file of the prime factors of the first N
% integers. N is specified by the user.
%
% LAST UPDATED by Andy French April 2016

function primefactors

%Display message to command window
disp(' ')
disp(' %%%%%%%%%%%%%%%%%%%%%%%%' )
disp('  Generate prime factors ' )
disp(' %%%%%%%%%%%%%%%%%%%%%%%%' )
disp(' ')
disp(' Specify largest integer (default is 1000)')
N = input(' > N = ');
if isempty(N)
    N = 1000;
    disp(' N = 1000')
end
disp(' ');
disp(' .... Computing factors ')
disp(' ');

%Start clock
t0 = tic;

%Initialise a cell array in which to store prime factor description
%e.g. 123 = 3 x 41 or 17* (*denotes a prime number)
c = cell(N,1);

%Step through numbers and work out prime factors. Update s accordingly
for n=1:N
    %Compute a vector of prime factors of integer n
    f = factor(n);
    
    %Is n prime? If so append with a *
    if isprime(n) == 1
        c{n} = [ num2str(n),'*' ];
    else
        %Number is not prime. Loop through factors e.g. 1234 = 2 x 617
        c{n} = [num2str(n),' = '];
        for k=1:numel(f)
            c{n} = [c{n}, num2str( f(k) ),' x '];
        end
        %Remove last ' x '
        c{n} = c{n}( 1: end-3 );
    end    
end

% Write out an Excel sheet
% xlswrite( ['Prime factors of 1-',num2str(N),'.xls'], c );

%Convert the cell array to a string, adding line return character char(10)
s = [];
for n=1:numel(c)
    s = [ s, c{n},char(10)];
end

%Open a text file. The w+ option will discard the content of any file of
%the same name. fid is a 'file identifier'
fid = fopen( ['Prime factors of 1-',num2str(N),'.txt'],'w+');

%Write then close the file
fwrite(fid, s, 'char' );
fclose(fid);

%Display completion message
disp([ ' .... Text file of prime factors created in ',num2str(toc(t0)),' seconds.'] );
disp(' ')

%End of code